@@ -161,6 +161,12 @@ class _WithPhotoUrl(_Base):
     photo_url: Optional[str] = None
 
 
+@dataclass
+class _WithProfilePicture(_Base):
+    #: Account's profile picture.
+    profile_picture: Optional[str] = None
+
+
 @dataclass
 class _WithNeedConfirmation(_Base):
     #: Whether another account with the same credential already exists.
@@ -285,8 +291,6 @@ class SignUpUser(
 
 @dataclass
 class SignInWithPasswordUser(
-    _WithDisplayName,
-    _WithPhotoUrl,
     _WithUserBasic,
     _WithResponseKind,
     _WithEmail,
